@@ -121,21 +121,31 @@ snapshot_formatters = [
         Formatter('<recency-sz histogram>',
                   lambda snapshot, record, fmt:
                   recency_hist_str(snapshot, record, fmt, False),
-                  'last accessed time to total size of the regions histogram'),
+                  'idle time to total size of the regions histogram'),
         Formatter('<recency-df-passed-sz histogram>',
                   lambda snapshot, record, fmt:
                   recency_hist_str(snapshot, record, fmt, True),
-                  ' '.join(['last accessed time to total size of',
+                  ' '.join(['idle time to total size of',
                             'DAMOS filters (df) passed regions histogram'])),
         Formatter('<recency percentiles>',
                   lambda snapshot, record, fmt:
                   recency_percentiles(snapshot, record, fmt, False),
-                  'per-byte last accessed time distribution in percentiles'),
+                  'per-byte idle time distribution in percentiles'),
         Formatter('<df-passed recency percentiles>',
                   lambda snapshot, record, fmt:
                   recency_percentiles(snapshot, record, fmt, True),
-                  ' '.join(['per-df-passed byte last accessed time',
+                  ' '.join(['per-df-passed byte idle time',
                             'distribution in percentiles'])),
+        Formatter('<temperature percentiles>',
+                  lambda snapshot, record, fmt:
+                  temperature_percentiles(snapshot, record, fmt, False),
+                  'per-byte access temperature distribution in percentiles'),
+        Formatter('<df-passed temperature percentiles>',
+                  lambda snapshot, record, fmt:
+                  temperature_percentiles(snapshot, record, fmt, True),
+                  ' '.join(['per-df-passed byte access temperature',
+                            'distribution in percentiles'])),
+
         Formatter('<heatmap>',
                   lambda snapshot, record, fmt:
                   heatmap_str(snapshot, record, fmt),
@@ -373,14 +383,14 @@ def histogram_str(hist):
         lines.append('%s %s %s' % (xrange_str, y_str, bar))
     return '\n'.join(lines)
 
-def get_unsorted_histogram(snapshot, fmt, get_x_fn, get_y_fn):
-    hist = {}
+def get_distribution(snapshot, fmt, get_metric_fn, aggr_us, get_count_fn):
+    dist = {}
     for region in snapshot.regions:
-        xval = get_x_fn(region, fmt)
-        if not xval in hist:
-            hist[xval] = 0
-        hist[xval] += get_y_fn(region, fmt)
-    return hist
+        metric_val = get_metric_fn(region, fmt, aggr_us)
+        if not metric_val in dist:
+            dist[metric_val] = 0
+        dist[metric_val] += get_count_fn(region, fmt)
+    return dist
 
 def get_sorted_ranged_historgram(
         hist, fmt, fmt_x_fn, parse_x_fn, fmt_y_fn, y_aggr_fn):
@@ -413,72 +423,72 @@ def get_sz_region(region, fmt):
 def get_df_passed_sz_region(region, fmt):
     return region.sz_filter_passed
 
-def sz_hist_str(snapshot, fmt, df_passed_sz, get_metric_fn, fmt_metric_fn,
-                parse_metric_fn):
+def sz_hist_str(snapshot, fmt, df_passed_sz, get_metric_fn, aggr_us,
+                fmt_metric_fn, parse_metric_fn):
     if len(snapshot.regions) == 0:
         return 'no region in snapshot'
     if df_passed_sz is True:
-        get_y_fn = get_df_passed_sz_region
+        get_count_fn = get_df_passed_sz_region
     else:
-        get_y_fn = get_sz_region
-    hist = get_unsorted_histogram(snapshot, fmt, get_metric_fn, get_y_fn)
-    hist2 = get_sorted_ranged_historgram(
-            hist, fmt, fmt_metric_fn, parse_metric_fn, _damo_fmt_str.format_sz,
+        get_count_fn = get_sz_region
+    dist = get_distribution(
+            snapshot, fmt, get_metric_fn, aggr_us, get_count_fn)
+    hist = get_sorted_ranged_historgram(
+            dist, fmt, fmt_metric_fn, parse_metric_fn, _damo_fmt_str.format_sz,
             lambda sz_list: sum(sz_list))
 
-    return histogram_str(hist2)
+    return histogram_str(hist)
+
+def get_temperature(region, fmt, aggr_us):
+    # set size weight zero
+    weights = [0, fmt.temperature_weights[1], fmt.temperature_weights[2]]
+    return temperature_of(region, weights)
 
 def temperature_sz_hist_str(snapshot, record, fmt, df_passed_sz):
-    def get_temperature(region, fmt):
-        # set size weight zero
-        weights = [0, fmt.temperature_weights[1], fmt.temperature_weights[2]]
-        return temperature_of(region, weights)
+    return sz_hist_str(
+            snapshot, fmt, df_passed_sz, get_temperature,
+            record.intervals.aggr, _damo_fmt_str.format_nr,
+            _damo_fmt_str.text_to_nr)
 
-    return sz_hist_str(snapshot, fmt, df_passed_sz, get_temperature,
-                       _damo_fmt_str.format_nr, _damo_fmt_str.text_to_nr)
-
-def get_last_used_time(region, fmt):
+def get_idle_time(region, fmt, aggr_interval):
     if region.nr_accesses.percent > 0:
         return 0
-    return region.age.usec
+    return region.age.usec + aggr_interval
 
 def recency_hist_str(snapshot, record, fmt, df_passed_sz):
     if len(snapshot.regions) == 0:
         return 'no region in snapshot'
 
-    get_metric_fn = get_last_used_time
-    fmt_metric_fn = _damo_fmt_str.format_time_us
-    parse_metric_fn = _damo_fmt_str.text_to_us
+    return sz_hist_str(
+            snapshot, fmt, df_passed_sz, get_idle_time, record.intervals.aggr,
+            _damo_fmt_str.format_time_us, _damo_fmt_str.text_to_us)
 
-    if df_passed_sz is True:
-        get_y_fn = get_df_passed_sz_region
+def get_percentiles_to_show(fmt):
+    percentiles_range = fmt.percentiles_range
+    if percentiles_range is None:
+        percentiles_to_show = [0, 1, 25, 50, 75, 99, 100]
     else:
-        get_y_fn = get_sz_region
-    y_fmt_fn = _damo_fmt_str.format_sz
-    y_aggr_fn = lambda vals: sum(vals)
+        if len(percentiles_range) <= 3:
+            percentiles_to_show = list(range(*percentiles_range))
+        else:
+            percentiles_to_show = sorted(percentiles_range)
+    return percentiles_to_show
 
-    hist = get_unsorted_histogram(snapshot, fmt, get_metric_fn, get_y_fn)
-    hist2 = get_sorted_ranged_historgram(
-            hist, fmt, fmt_metric_fn, parse_metric_fn, y_fmt_fn, y_aggr_fn)
-
-    return histogram_str(hist2)
-
-def recency_percentiles(snapshot, record, fmt, df_passed):
-    if len(snapshot.regions) == 0:
-        return 'no region in snapshot'
+def get_percentile_values(snapshot, record, recency_or_temperature, df_passed,
+                          percentiles_to_show, fmt):
+    if recency_or_temperature == 'recency':
+        get_metric_fn = get_idle_time
+    else:
+        get_metric_fn = get_temperature
+    aggr_us = record.intervals.aggr
     regions = sorted(snapshot.regions,
-                     key=lambda r: get_last_used_time(r, fmt))
+                     key=lambda r: get_metric_fn(r, fmt, aggr_us))
     if df_passed is True:
         total_sz = sum(r.sz_filter_passed for r in regions)
     else:
         total_sz = sum(r.size() for r in regions)
-    percentiles_to_show = [0, 1, 25, 50, 75, 99]
-    percentile = 0
     percentile_values = []
-    if df_passed is True:
-        lines = ['<df-passed percentile> <last accessed time>']
-    else:
-        lines = ['<percentile> <last accessed time>']
+    percentile = 0
     for r in regions:
         if df_passed is True:
             percentile += r.sz_filter_passed * 100 / total_sz
@@ -488,11 +498,41 @@ def recency_percentiles(snapshot, record, fmt, df_passed):
             if percentile < percentiles_to_show[0]:
                 break
             percentile_values.append(
-                    [percentiles_to_show[0], get_last_used_time(r, fmt)])
+                    [percentiles_to_show[0], get_metric_fn(r, fmt, aggr_us)])
             percentiles_to_show = percentiles_to_show[1:]
         if percentile >= 100.0:
             break
-    percentile_values.append([100, get_last_used_time(r, fmt)])
+    if 100 in percentiles_to_show:
+        percentile_values.append([100, get_metric_fn(r, fmt, aggr_us)])
+    return percentile_values
+
+def fmt_percentile_str_head(recency_or_temperature, df_passed, fmt):
+    if recency_or_temperature == 'recency':
+        if fmt.raw_number:
+            legend_str = '<idle time (us)>'
+        else:
+            legend_str = '<idle time>'
+    else:
+        legend_str = '<temperature (weights: %s)>' % fmt.temperature_weights
+    if df_passed is True:
+        return '<df-passed percentile> %s' % legend_str
+    else:
+        return '<percentile> %s' % legend_str
+
+def fmt_percentile_str(percentile_values, fmt, recency_or_temperature,
+                       df_passed):
+    lines = [fmt_percentile_str_head(recency_or_temperature, df_passed, fmt)]
+    if recency_or_temperature == 'recency':
+        fmt_fn = _damo_fmt_str.format_time_us
+    else:
+        fmt_fn = _damo_fmt_str.format_nr
+    percentile_txts = []
+    idletime_txts = []
+    bars = []
+    percentile_txts = ['%d' % p for p, v in percentile_values]
+    max_percentile_txt_len = max([len(p) for p in percentile_txts])
+    idletime_txts = [fmt_fn(v, fmt.raw_number) for p, v in percentile_values]
+    max_idletime_txt_len = max([len(i) for i in idletime_txts])
 
     min_val = percentile_values[0][-1]
     max_val = percentile_values[-1][-1]
@@ -501,14 +541,36 @@ def recency_percentiles(snapshot, record, fmt, df_passed):
         val_per_dot = (max_val - min_val) / max_dots
     else:
         val_per_dot = 1
-    for percentile, val in percentile_values:
-        bar_length = int((val - min_val) / val_per_dot)
+
+    for idx, percentile_txt in enumerate(percentile_txts):
+        percentile_padding = ' ' * (max_percentile_txt_len -
+                                    len(percentile_txt))
+        idletime_txt = idletime_txts[idx]
+        idletime_padding = ' ' * (max_idletime_txt_len - len(idletime_txt))
+        bar_length = int((percentile_values[idx][1] - min_val) / val_per_dot)
         bar = '|%s%s|' % ('*' * bar_length, ' ' * (max_dots - bar_length))
-        lines.append(
-                '%3d %18s %s' %
-                (percentile, _damo_fmt_str.format_time_us(val, fmt.raw), bar))
+        lines.append('%s%s  %s%s  %s' % (
+            percentile_padding, percentile_txt,
+            idletime_padding, idletime_txt, bar))
     return '\n'.join(lines)
 
+def percentiles_str(snapshot, record, fmt, df_passed, recency_or_temperature):
+    if len(snapshot.regions) == 0:
+        return 'no region in snapshot'
+
+    percentiles_to_show = get_percentiles_to_show(fmt)
+    percentile_values = get_percentile_values(
+            snapshot, record, recency_or_temperature, df_passed,
+            percentiles_to_show, fmt)
+    return fmt_percentile_str(percentile_values, fmt, recency_or_temperature,
+                              df_passed)
+
+def recency_percentiles(snapshot, record, fmt, df_passed):
+    return percentiles_str(snapshot, record, fmt, df_passed, 'recency')
+
+def temperature_percentiles(snapshot, record, fmt, df_passed):
+    return percentiles_str(snapshot, record, fmt, df_passed, 'temperature')
+
 def temperature_str(region, raw, fmt):
     temperature = temperature_of(region, fmt.temperature_weights)
     return _damo_fmt_str.format_nr(temperature, raw)
@@ -576,24 +638,11 @@ class HeatPixel:
             region.end = end
         self.total_heat += temperature_of(region, weights) * (region.size())
 
-def heatmap_str(snapshot, record, fmt):
-    if len(snapshot.regions) == 0:
-        return 'n/a (no region)'
-    raw = fmt.raw_number
-    static = fmt.snapshot_heatmap_static
-    if static:
-        total_sz = snapshot.regions[-1].end - snapshot.regions[0].start
-    else:
-        total_sz = 0
-        for region in snapshot.regions:
-            total_sz += region.size()
-    map_length = fmt.snapshot_heatmap_width
-    sz_unit = total_sz / map_length
-
-    start = snapshot.regions[0].start
+def heatmap_pixels_minmax_temps(snapshot, sz_unit, fmt):
     pixels = []
     min_temperature = None
     max_temperature = None
+    start = snapshot.regions[0].start
     while start < snapshot.regions[-1].end:
         end = start + sz_unit
         pixels.append(HeatPixel(
@@ -611,7 +660,9 @@ def heatmap_str(snapshot, record, fmt):
             if max_temperature is None or pixel.temperature > max_temperature:
                 max_temperature = pixel.temperature
             start = end
+    return pixels, min_temperature, max_temperature
 
+def heatmap_dots(pixels, min_temperature, max_temperature, fmt):
     max_color_level = _damo_ascii_color.max_color_level()
     temperature_unit = (max_temperature - min_temperature) / max_color_level
     # single region?
@@ -632,7 +683,27 @@ def heatmap_str(snapshot, record, fmt):
                 (pixel.temperature - min_temperature) / temperature_unit)
         dots.append(_damo_ascii_color.colored(
             '%d' % temp_level, fmt.snapshot_heatmap_colorset, temp_level))
-    dots = ''.join(dots)
+    return ''.join(dots)
+
+def heatmap_str(snapshot, record, fmt):
+    if len(snapshot.regions) == 0:
+        return 'n/a (no region)'
+    raw = fmt.raw_number
+    # whether to display monitoring gaps as size-relative or not
+    static = fmt.snapshot_heatmap_static
+    if static:
+        total_sz = snapshot.regions[-1].end - snapshot.regions[0].start
+    else:
+        total_sz = 0
+        for region in snapshot.regions:
+            total_sz += region.size()
+    map_length = fmt.snapshot_heatmap_width
+    sz_unit = total_sz / map_length
+
+    pixels, min_temperature, max_temperature = heatmap_pixels_minmax_temps(
+            snapshot, sz_unit, fmt)
+    dots = heatmap_dots(pixels, min_temperature, max_temperature, fmt)
+
     comment = '# min/max temperatures: %s, %s, column size: %s' % (
             _damo_fmt_str.format_nr(min_temperature, raw),
             _damo_fmt_str.format_nr(max_temperature, raw),
@@ -1087,6 +1158,7 @@ class ReportFormat:
         self.hist_logscale = args.hist_logscale
         self.hist_cumulate = args.hist_cumulate
         self.hist_ranges = args.hist_ranges
+        self.percentiles_range = args.percentiles_range
         self.format_record_head = args.format_record_head
         self.format_record_tail = args.format_record_tail
         self.format_snapshot_head = args.format_snapshot_head
@@ -1095,7 +1167,8 @@ class ReportFormat:
         self.snapshot_heatmap_width = args.snapshot_heatmap_width
         self.snapshot_heatmap_static = args.snapshot_heatmap_static
         self.snapshot_heatmap_colorset = args.snapshot_heatmap_colorset
-        self.region_box_values = args.region_box_values
+        self.region_box_values = [
+                v if v != 'none' else None for v in args.region_box_values]
         self.region_box_min_max_height = args.region_box_min_max_height
         self.region_box_min_max_length = args.region_box_min_max_length
         self.region_box_colorset = args.region_box_colorset
@@ -1122,6 +1195,7 @@ class ReportFormat:
                 'hist_logscale': self.hist_logscale,
                 'hist_cumulate': self.hist_cumulate,
                 'hist_ranges': self.hist_ranges,
+                'percentiles_range': self.percentiles_range,
                 'format_record_head': self.format_record_head,
                 'format_record_tail': self.format_record_tail,
                 'format_snapshot_head': self.format_snapshot_head,
@@ -1163,6 +1237,9 @@ class ReportFormat:
             self.hist_ranges = kvpairs['hist_ranges']
         else:
             self.hist_ranges = None
+        # percentiles_range introduced after v2.8.0
+        if 'percentiles_range' in kvpairs:
+            self.percentiles_range = kvpairs['percentiles_range']
         self.format_record_head = kvpairs['format_record_head']
         self.format_record_tail = kvpairs['format_record_tail']
         self.format_snapshot_head = kvpairs['format_snapshot_head']
@@ -1208,7 +1285,7 @@ def set_formats_hist_style(args, fmt, records):
         filter_passed_hist_keyword = '<temperature-df-passed-sz histogram>'
     else:
         # args.style == 'recency-sz-hist':
-        legend = '<last accessed time (us)>'
+        legend = '<idle time (us)>'
         hist_keyword = '<recency-sz histogram>'
         filter_passed_hist_keyword = '<recency-df-passed-sz histogram>'
 
@@ -1221,40 +1298,67 @@ def set_formats_hist_style(args, fmt, records):
     fmt.format_snapshot_head = '\n'.join(snapshot_head_content)
     fmt.format_region = ''
 
-def set_formats(args, records):
-    fmt = ReportFormat.from_args(args)
+def set_formats_percentiles(args, fmt, records, recency_or_temperature):
+    snapshot_head_content = []
+    if has_ops_filters(records):
+        snapshot_head_content += [
+                '# damos filters (df): <filters passed type>',
+                '# df-passed %s percentiles' % recency_or_temperature]
+        if recency_or_temperature == 'recency':
+            snapshot_head_content.append('<df-passed recency percentiles>')
+        else:
+            snapshot_head_content.append('<df-passed temperature percentiles>')
+        snapshot_head_content.append('')
+    if recency_or_temperature == 'recency':
+        snapshot_head_content += [
+                '# total recency percentiles',
+                '<recency percentiles>',
+                ]
+    else:
+        snapshot_head_content += [
+                '# total temperature percentiles',
+                '<temperature percentiles>',
+                ]
+    fmt.format_snapshot_head = '\n'.join(snapshot_head_content)
+    fmt.format_region = ''
 
-    if args.format is not None:
-        if len(args.format) == 1 and len(args.format[0]) == 1:
-            fmt_string = args.format[0][0]
-            if os.path.isfile(fmt_string):
-                with open(fmt_string, 'r') as f:
-                    fmt_string = f.read()
-            try:
-                return ReportFormat.from_kvpairs(json.loads(fmt_string)), None
-            except:
-                return None, 'wrong --format option'
-        for format_fields in args.format:
-            if len(format_fields) != 3:
-                return None, 'wrong --format option (%s)' % format_fields
-            action, target_area, fmt_string = format_fields
-            if not action in ['set', 'append']:
-                return None, 'wrong --format action (%s)' % format_fields
-            if not target_area in ['record_head', 'snapshot_head', 'region',
-                                   'snapshot_tail', 'record_tail']:
-                return None, 'wrong --format target area (%s)' % format_fields
-            if action == 'set':
-                if target_area == 'record_head':
-                    fmt.format_record_head = fmt_string
-                elif target_area == 'snapshot_head':
-                    fmt.format_snapshot_head = fmt_string
-                elif target_area == 'region':
-                    fmt.format_region = fmt_string
-                elif target_area == 'snapshot_tail':
-                    fmt.format_snapshot_tail = fmt_string
-                elif target_area == 'record_tail':
-                    fmt.format_record_tail = fmt_string
+def set_formats_handle_format_set_arg(fmt, format_arg):
+    '''Handle --format inputs except 'append' ones'''
+    if format_arg is None:
+        return
+    if len(format_arg) == 1 and len(format_arg[0]) == 1:
+        fmt_string = format_arg[0][0]
+        if os.path.isfile(fmt_string):
+            with open(fmt_string, 'r') as f:
+                fmt_string = f.read()
+        try:
+            return ReportFormat.from_kvpairs(json.loads(fmt_string)), None
+        except:
+            return None, 'wrong --format option'
+    for format_fields in format_arg:
+        if len(format_fields) != 3:
+            return None, 'wrong --format option (%s)' % format_fields
+        action, target_area, fmt_string = format_fields
+        if not action in ['set', 'append']:
+            return None, 'wrong --format action (%s)' % format_fields
+        if not target_area in ['record_head', 'snapshot_head', 'region',
+                               'snapshot_tail', 'record_tail']:
+            return None, 'wrong --format target area (%s)' % format_fields
+        if action == 'set':
+            if target_area == 'record_head':
+                fmt.format_record_head = fmt_string
+            elif target_area == 'snapshot_head':
+                fmt.format_snapshot_head = fmt_string
+            elif target_area == 'region':
+                fmt.format_region = fmt_string
+            elif target_area == 'snapshot_tail':
+                fmt.format_snapshot_tail = fmt_string
+            elif target_area == 'record_tail':
+                fmt.format_record_tail = fmt_string
 
+def set_formats_handle_styles(fmt, args, records):
+    if args.style is None:
+        return
     if args.style == 'simple-boxes':
         fmt.format_snapshot_head = default_snapshot_head_format_without_heatmap
         fmt.format_region = '<box> size <size> access rate <access rate> age <age>'
@@ -1264,6 +1368,10 @@ def set_formats(args, records):
         fmt.region_box_colorset = 'emotion'
     elif args.style in ['temperature-sz-hist', 'recency-sz-hist']:
         set_formats_hist_style(args, fmt, records)
+    elif args.style == 'recency-percentiles':
+        set_formats_percentiles(args, fmt, records, 'recency')
+    elif args.style == 'temperature-percentiles':
+        set_formats_percentiles(args, fmt, records, 'temperature')
     elif args.style == 'cold':
         fmt.format_region = '<box> <size> access <access rate> <age>'
         fmt.region_box_min_max_height = [1, 1]
@@ -1280,55 +1388,19 @@ def set_formats(args, records):
         fmt.sort_regions_by = ['temperature']
         fmt.sort_regions_dsc = ['temperature']
 
-    fmt.region_box_values = [v if v != 'none' else None
-            for v in args.region_box_values]
-
-    if args.total_sz_only:
-        fmt.format_snapshot_head = ''
-        fmt.format_region = ''
-        fmt.format_snapshot_tail = '<total bytes>'
-
-    if args.region_box:
-        if fmt.region_box_min_max_height[1] > 1:
-            fmt.format_region = '<box>%s' % default_region_format
-        else:
-            fmt.format_region = '<box>\n%s' % default_region_format
-        if fmt.format_snapshot_tail.find('<region box description>') == -1:
-            fmt.format_snapshot_tail = ('%s\n<region box description>' %
-                    fmt.format_record_tail)
-    if len(records) == 0:
-        return fmt, None
-
+def set_formats_record_default(fmt, records, intervals_tuning_enabled):
     if fmt.format_record_head == None:
         if len(records) > 1:
             fmt.format_record_head = default_record_head_format
         else:
             fmt.format_record_head = ''
+    if fmt.format_record_tail is None and intervals_tuning_enabled:
+        fmt.format_record_tail = 'monitoring intervals: <intervals>'
+    if fmt.format_record_tail is None:
+        fmt.format_record_tail = ''
 
-    if fmt.format_region == default_region_format:
-        for record in records:
-            if len(record.scheme_filters) > 0:
-                fmt.format_region += ' df-passed <filters passed bytes>'
-                break
-
-    ops_filters_installed = False
-    intervals_tuning_enabled = False
-    for record in records:
-        if len(record.scheme_filters) > 0:
-            ops_filters_installed = True
-        if record.intervals is not None:
-            if record.intervals.intervals_goal.enabled():
-                intervals_tuning_enabled = True
-        if ops_filters_installed and intervals_tuning_enabled:
-            break
-
-    if fmt.format_snapshot_tail == default_snapshot_tail_format:
-        if ops_filters_installed:
-            fmt.format_snapshot_tail = default_snapshot_tail_format_filter_installed
-        # further check if scheme action is not stat
-        if args.tried_regions_of is not None:
-            fmt.format_snapshot_tail += '\nscheme stats\n<damos stats>'
-
+def set_formats_snapshot_default(fmt, records, args, ops_filters_installed):
+    # handle snapshot head and tail
     if fmt.format_snapshot_head == None:
         need_snapshot_head = False
         for record in records:
@@ -1343,23 +1415,77 @@ def set_formats(args, records):
         fmt.format_snapshot_head += '\n# damos filters (df): <filters passed type>'
         fmt.format_snapshot_head += '\ndf-pass: <filters passed heatmap>'
 
-    if fmt.format_record_tail == '' and intervals_tuning_enabled:
-        fmt.format_record_tail = 'monitoring intervals: <intervals>'
+    if args.region_box:
+        if fmt.format_snapshot_tail.find('<region box description>') == -1:
+            fmt.format_snapshot_tail = ('%s\n<region box description>' %
+                    fmt.format_record_tail)
 
-    if args.format is not None:
-        for action, target_area, fmt_string in args.format:
-            if action == 'append':
-                if target_area == 'record_head':
-                    fmt.format_record_head += fmt_string
-                elif target_area == 'snapshot_head':
-                    fmt.format_snapshot_head += fmt_string
-                elif target_area == 'region':
-                    fmt.format_region += fmt_string
-                elif target_area == 'snapshot_tail':
-                    fmt.format_snapshot_tail += fmt_string
-                elif target_area == 'record_tail':
-                    fmt.format_record_tail += fmt_string
+    if fmt.format_snapshot_tail == default_snapshot_tail_format:
+        if ops_filters_installed:
+            fmt.format_snapshot_tail = default_snapshot_tail_format_filter_installed
+        # further check if scheme action is not stat
+        if args.tried_regions_of is not None:
+            fmt.format_snapshot_tail += '\nscheme stats\n<damos stats>'
 
+def set_formats_region_default(fmt, records, args):
+    if args.region_box:
+        if fmt.region_box_min_max_height[1] > 1:
+            fmt.format_region = '<box>%s' % default_region_format
+        else:
+            fmt.format_region = '<box>\n%s' % default_region_format
+
+    if fmt.format_region == default_region_format:
+        for record in records:
+            if len(record.scheme_filters) > 0:
+                fmt.format_region += ' df-passed <filters passed bytes>'
+                break
+
+def set_formats_update_default_formats(fmt, records, args):
+    ops_filters_installed = False
+    intervals_tuning_enabled = False
+    for record in records:
+        if len(record.scheme_filters) > 0:
+            ops_filters_installed = True
+        if record.intervals is not None:
+            if record.intervals.intervals_goal.enabled():
+                intervals_tuning_enabled = True
+        if ops_filters_installed and intervals_tuning_enabled:
+            break
+
+    set_formats_record_default(fmt, records, intervals_tuning_enabled)
+    set_formats_snapshot_default(fmt, records, args, ops_filters_installed)
+    set_formats_region_default(fmt, records, args)
+
+def set_formats_handle_format_append_arg(fmt, format_args):
+    if format_args is None:
+        return
+    for action, target_area, fmt_string in format_args:
+        if action != 'append':
+            continue
+        if target_area == 'record_head':
+            fmt.format_record_head += fmt_string
+        elif target_area == 'snapshot_head':
+            fmt.format_snapshot_head += fmt_string
+        elif target_area == 'region':
+            fmt.format_region += fmt_string
+        elif target_area == 'snapshot_tail':
+            fmt.format_snapshot_tail += fmt_string
+        elif target_area == 'record_tail':
+            fmt.format_record_tail += fmt_string
+
+def set_formats(args, records):
+    fmt = ReportFormat.from_args(args)
+
+    set_formats_handle_format_set_arg(fmt, args.format)
+    set_formats_handle_styles(fmt, args, records)
+
+    if args.total_sz_only:
+        fmt.format_snapshot_head = ''
+        fmt.format_region = ''
+        fmt.format_snapshot_tail = '<total bytes>'
+
+    set_formats_update_default_formats(fmt, records, args)
+    set_formats_handle_format_append_arg(fmt, args.format)
     return fmt, None
 
 def handle_ls_keywords(args):
@@ -1558,10 +1684,17 @@ def add_fmt_args(parser, hide_help=False):
     parser.add_argument(
             '--style', choices=['detailed', 'simple-boxes',
                                 'temperature-sz-hist', 'recency-sz-hist',
+                                'recency-percentiles',
+                                'temperature-percentiles',
                                 'cold', 'hot'],
             default='detailed',
             help='output format selection among pre-configures ones')
     # how to show, in highly tunable way
+    parser.add_argument(
+            '--percentiles_range', nargs='+', type=int, metavar='<number>',
+            help='Percentiles to show.  If <=3 arguments are given, '
+            'ranges are made with Python range() function. '
+            'If >3 argumenta are given, show percentiles of each argument.')
     parser.add_argument(
             '--sort_regions_by', nargs='+',
             choices=['address', 'access_rate', 'age', 'size', 'temperature'],
@@ -1606,7 +1739,6 @@ def add_fmt_args(parser, hide_help=False):
             # help='output format to show at the beginning of each record'
             help=argparse.SUPPRESS)
     parser.add_argument('--format_record_tail', metavar='<template>',
-                        default='',
                         # help='output format to show at the end of each record'
                         help=argparse.SUPPRESS)
     parser.add_argument(
